meta:
  id: frame_tlm_amicalsat
  title: AMICALSAT TLM Frame
  file-extension: .data
  license:  LGPL V2
  ks-version: 0.8
  endian: be

  

seq:
  - id: frame_tlm_entry_sat
    type: ax25_frame
    doc-ref: 'https://www.tapr.org/pub_ax25.html'

types:
  ax25_frame:
    seq:
    - id: ax25_header
      type: ax25_header
    - id: payload
      type: i_frame

  ax25_header:
    seq:
      - id: dest_callsign_raw
        type: dest_callsign_raw
      - id: dest_ssid_raw
        type: u1
      - id: src_callsign_raw
        type: src_callsign_raw
      - id: src_ssid_raw
        type: u1
      - id: ctl
        type: u1
    instances:
      src_ssid:
        value: (src_ssid_raw & 0x0f) >> 1
      dest_ssid:
        value: (dest_ssid_raw & 0x0f) >> 1
  dest_callsign_raw:
    seq:
      - id: dest_callsign_ror
        process: ror(1)
        size: 6
        type: dest_callsign
  src_callsign_raw:
    seq:
      - id: src_callsign_ror
        process: ror(1)
        type: src_callsign
        size: 6
  dest_callsign:
    seq:
      - id: dest_callsign
        type: str
        encoding: ASCII
        size: 6
  src_callsign:
    seq:
      - id: src_callsign
        type: str
        encoding: ASCII
        size: 6

  i_frame:
    seq:
      - id: pid
        type: u1
      - id: field
        type: str
        encoding: ASCII
        terminator: 0x3D
      - id: tlmarea
        type: str
        encoding: ASCII
        terminator: 0x3B
      - id: tlmtype
        type: str
        encoding: ASCII
        terminator: 0x3B
 
      - id: tlmareaswitch
        type:
          switch-on: tlmarea
          cases: 
            '"M1"': m1type
            '"A1"': a1type               
            '"EM"': emtype
#            '"ER"': ertype  
#            '"V1"': v1u2type
#            '"U2"': v1u2type
#            '"CU_R"' : cutype                            
#            '"CU_L"' : cutype
      
        
        
  m1type:
    seq:       
      - id: timestamps
        type: str
        encoding: ASCII
        terminator: 0x3B     
      - id: tlmsw
        type:
          switch-on:  _parent.tlmtype
          cases: 
            '"LOG"': logtype
            '"FLAGS"': flagtype
                        
      - id: ax25_info
        size-eos: true


  a1type:
    seq:       
      - id: tlmsw
        type:
          switch-on:  _parent.tlmtype
          cases: 
            '"FLAGS"': a1flagtype
            '"MAG"': a1magtype
            '"GYRO"' : a1gyrotype
            '"POSITION"' : a1positiontype

  emtype:
    seq:       
      - id: timestamps
        type: str
        encoding: ASCII
        terminator: 0x3B     
      - id: tlmsw
        type:
          switch-on:  _parent.tlmtype
          cases: 
            '"LOG"': emlogtype
            '"MN"': emmntype


#M1;LOG;[Timestamp];[Boot number];[Up time];[CPU voltage];[CPU temperature]     
  logtype:
    seq:
      - id: bootnumber
        type: str
        encoding: ASCII
        terminator: 0x3B
      - id: uptime
        type: str
        encoding: ASCII
        terminator: 0x3B
      - id: cpuvoltage
        type: str
        encoding: ASCII
        terminator: 0x3B
      - id: cputemperature
        type: str
        encoding: ASCII
        size-eos: true
        
#M1;FLAGS;[Timestamp];[Hex flags]
# to do         
  flagtype:
    seq:
      - id: hexflags
        type: str
        encoding: ASCII
        size-eos: true
        
        
#A1;FLAGS;[mode];[flags];[faults]      

  a1flagtype:
    seq:
      - id: mode
        type: str
        encoding: ASCII
        terminator: 0x3B
      - id: a1flags
        type: str
        encoding: ASCII
        terminator: 0x3B
      - id: faults
        type: str
        encoding: ASCII
        size-eos: true
        
#A1;MAG;[Current timestamp];[MagX];[MagY];[MagZ]
  a1magtype:
    seq:
      - id: timestamps
        type: str
        encoding: ASCII
        terminator: 0x3B     
      - id: magx
        type: str
        encoding: ASCII
        terminator: 0x3B
      - id: magy
        type: str
        encoding: ASCII
        terminator: 0x3B
      - id: magz
        type: str
        encoding: ASCII
        size-eos: true

#A1;GYRO;[Current timestamp];[GyroX];[GyroY];[GyroZ]
  a1gyrotype:
    seq:
      - id: timestamps
        type: str
        encoding: ASCII
        terminator: 0x3B     
      - id: girox
        type: str
        encoding: ASCII
        terminator: 0x3B
      - id: giroy
        type: str
        encoding: ASCII
        terminator: 0x3B
      - id: giroz
        type: str
        encoding: ASCII
        size-eos: true

#A1;POSITION;[Current timestamp];[Latitude];[Longitude]
  a1positiontype:
    seq:
      - id: timestamps
        type: str
        encoding: ASCII
        terminator: 0x3B     
      - id: latitude
        type: str
        encoding: ASCII
        terminator: 0x3B
      - id: longitude
        type: str
        encoding: ASCII
        size-eos: true

#[EM/ER];MN;[Timestamp];[V in];[V solar];[I in];[P in];[P peak];[T cpu];[V cpu]

  emmntype:
    seq:
      - id: vin
        type: str
        encoding: ASCII
        terminator: 0x3B
      - id: vsolar
        type: str
        encoding: ASCII
        terminator: 0x3B
      - id: iin
        type: str
        encoding: ASCII
        terminator: 0x3B
      - id: pin
        type: str
        encoding: ASCII
        terminator: 0x3B
      - id: ppeak
        type: str
        encoding: ASCII
        terminator: 0x3B
      - id: tcpu
        type: str
        encoding: ASCII
        terminator: 0x3B
      - id: vcpu
        type: str
        encoding: ASCII
        size-eos: true
        
#EM;LOG;[Timestamp];[Boot number];[Input voltage];[Input current];[Input power];[Peak Power];[Solar panel voltage]
  emlogtype:
    seq:
      - id: bootnumber
        type: str
        encoding: ASCII
        terminator: 0x3B
      - id: inputvoltage
        type: str
        encoding: ASCII
        terminator: 0x3B
      - id: inputcurrent
        type: str
        encoding: ASCII
        terminator: 0x3B
      - id: inputpower
        type: str
        encoding: ASCII
        terminator: 0x3B  
      - id: peakpower
        type: str
        encoding: ASCII
        terminator: 0x3B
      - id: solarpanelvoltage
        type: str
        encoding: ASCII
        size-eos: true          
        